<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-cpf',
'0_langue' => 'Kr&egrave;y&ograve;l ayisyen [hat]',
'0_liste' => 'spip-cpf@rezo.net',
'0_mainteneur' => 'pascale@rezo.net',

// A
'access_interface_graphique' => 'Tounen d&egrave;y&eacute; si lent&egrave;fas gwafik konple',
'access_mode_texte' => 'Afiche lent&egrave;fas t&egrave;ks senp',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Chanje atik-la',
'admin_modifier_auteur' => 'Chanje bagay pou lot&egrave;-a',
'admin_modifier_breve' => 'Chanje ti-nouv&egrave;l la',
'admin_modifier_mot' => 'Chanje mokle-a',
'admin_modifier_rubrique' => 'Chanje ribwik-la (pati-a nan sit sa-a)',
'admin_recalculer' => 'Kalkil ank&ograve; paj-la',
'afficher_trad' => 'afiche twadiksyon yo',
'alerte_maj_impossible' => '<<b>Atansyon&nbsp;!</b> Larnouv&egrave;lman pou baz SQL sou @version@ se pa posib, pet&egrave;t ka gen yon pwobl&egrave;m ek drwa pou chanje bazdone-a. Tanpri souple kontak l&eacute;b&egrave;j&egrave; ou.', # MODIF
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute; par ailleurs. La valeur actuelle est&nbsp;:', # MODIF
'analyse_xml' => 'Analiz XML',
'annuler' => 'Annuler', # NEW
'antispam_champ_vide' => 'Veuillez laisser ce champ vide&nbsp;:', # NEW
'articles_recents' => 'Atik yo ki plis resan',
'avis_archive_incorrect' => 'fichye achiv-a se pa fichye SPIP',
'avis_archive_invalide' => 'fichye achiv-a se pa kor&egrave;k',
'avis_attention' => 'ATANSYON&nbsp;!',
'avis_champ_incorrect_type_objet' => 'Kouman chan-a li ap rele, pou bagay-la, se pa korek @name@ pou loj&egrave; tip @type@',
'avis_colonne_inexistante' => 'Kol&ograve;n nan @col@ pa egziste kounye-a',
'avis_echec_syndication_01' => 'Sendikasyon te pa mache : "backend"  te rele konsa se pa posib f&eacute; lekti osnon se li pa pwopoze okenn atik kounye-a.',
'avis_echec_syndication_02' => 'Sendikasyon te pa mache : gen enposib aksede "backend" sit-la.',
'avis_erreur' => 'Er&egrave; : tanpri gad isit anba',
'avis_erreur_connexion' => 'Er&egrave; ak koneksyon',
'avis_erreur_cookie' => 'pwobl&egrave;m &egrave;k gatomakro (kouki)',
'avis_erreur_fonction_contexte' => 'Er&egrave; ak pwogwmasyon. Fok w pa rele fonksyon-nan andan kont&egrave;ks-la.', # MODIF
'avis_erreur_mysql' => 'Er&egrave; SQL', # MODIF
'avis_erreur_sauvegarde' => 'Er&egrave; nan sovgad (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'Pwobl&egrave;m pou antre nan lespas priv&eacute;',

// B
'barre_a_accent_grave' => 'M&egrave;t yon A aksan gwav majiskil',
'barre_aide' => 'Tichemen tipogwafik yo y f&eacute; yon paj pli b&egrave;l',
'barre_e_accent_aigu' => 'M&egrave;t yon E aksan &egrave;gi majiskil',
'barre_eo' => 'M&egrave;t yon E nan O',
'barre_eo_maj' => 'M&egrave;t yon E nan l&egrave;t O majiskil',
'barre_euro' => 'M&egrave;t senbol &euro;',
'barre_gras' => 'F&eacute; par&egrave;t &eacute;kri{{gra}}',
'barre_guillemets' => 'Pou m&egrave;t &laquo; giym&eacute; frans&eacute; yo &raquo;',
'barre_guillemets_simples' => 'Pou m&egrave;t &#132;giym&eacute;&#147; yo',
'barre_intertitre' => 'M&egrave;t bagay kon yon {{{lent&egrave;tit}}}',
'barre_italic' => 'F&eacute; par&egrave;t &eacute;kri {italik}',
'barre_lien' => 'Chanje pou yon [lyen ipet&egrave;ks->http://...]',
'barre_lien_input' => 'Tanpri souple enskri ladr&egrave;s lyen ou (posib enskri yon ladr&egrave;s w&egrave;b nan f&ograve;ma http://www.monsite/com osnon senpman enskri nimewo atik-la nan sit sa-a.',
'barre_note' => 'Chanje pou m&egrave;t yon [[Not enba la paj]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>Rap&ograve;t yon mesaj</quote>',
'bouton_ajouter_document' => 'AJOUTE YON DOKIMAN', # MODIF
'bouton_ajouter_image' => 'AJOUTE YON IMAJ', # MODIF
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Chanje',
'bouton_chercher' => 'Ch&egrave;che',
'bouton_choisir' => 'Chwazi',
'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
'bouton_enregistrer' => 'Enskri',
'bouton_radio_desactiver_messagerie_interne' => 'Rete kazmodekri',
'bouton_radio_envoi_annonces' => 'Voye anons leditoyal ',
'bouton_radio_non_envoi_annonces' => 'Rete voye anons yo',
'bouton_radio_non_envoi_liste_nouveautes' => 'Rete voye yon lis nouv&egrave;lte yo',
'bouton_recharger_page' => 'Chaje ank&ograve; paj-la',
'bouton_telecharger' => 'Telechaje',
'bouton_valider' => 'Konfime',

// C
'cal_apresmidi' => 'apr&eacute;midi',
'cal_jour_entier' => 'jou konpl&eacute;',
'cal_matin' => 'maten',
'cal_par_jour' => 'kalandrye pa jou',
'cal_par_mois' => 'kalandrye pa mwa',
'cal_par_semaine' => 'kalandrye pa sem&egrave;n',
'choix_couleur_interface' => 'koul&egrave;',
'choix_interface' => 'pou chwazi lentefas',
'colonne' => 'Colonne', # NEW
'confirm_changer_statut' => 'Atansyon. W te domann chanje lestati eleman nan. Eske w gen kontinye ?',
'correcte' => 'korek',

// D
'date_aujourdhui' => 'jodiya',
'date_avant_jc' => 'avan J.C.',
'date_dans' => 'nan @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'demen',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ a @heure@',
'date_fmt_jour_mois' => '@jour@ @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'nan jou ki te @nomjour@ @date@ -a',
'date_heures' => '&egrave;r (yo)',
'date_hier' => 'y&egrave;',
'date_il_y_a' => ' genyen @delai@',
'date_jnum1' => '1e',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'dimanch',
'date_jour_1_abbr' => 'dim.',
'date_jour_1_initiale' => 'd.',
'date_jour_2' => 'lendi',
'date_jour_2_abbr' => 'len.',
'date_jour_2_initiale' => 'l.',
'date_jour_3' => 'madi',
'date_jour_3_abbr' => 'mad.',
'date_jour_3_initiale' => 'm.',
'date_jour_4' => 'm&egrave;kredi',
'date_jour_4_abbr' => 'mek.',
'date_jour_4_initiale' => 'm.',
'date_jour_5' => 'jedi',
'date_jour_5_abbr' => 'jed.',
'date_jour_5_initiale' => 'j.',
'date_jour_6' => 'vandredi',
'date_jour_6_abbr' => 'van.',
'date_jour_6_initiale' => 'v.',
'date_jour_7' => 'sanmdi',
'date_jour_7_abbr' => 'sam.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'jou yo',
'date_minutes' => 'minit yo',
'date_mois' => 'mwa ',
'date_mois_1' => 'janvye',
'date_mois_10' => 'okt&ograve;b ',
'date_mois_11' => 'novanm',
'date_mois_12' => 'Desanm ',
'date_mois_2' => 'fevriye',
'date_mois_3' => 'mas',
'date_mois_4' => 'avril',
'date_mois_5' => 'me',
'date_mois_6' => 'jen',
'date_mois_7' => 'jiy&egrave; ',
'date_mois_8' => 'out',
'date_mois_9' => 'septanm',
'date_saison_1' => 'iv&egrave;',
'date_saison_2' => ' prentan',
'date_saison_3' => 'l&eacute;t&eacute;',
'date_saison_4' => 'lot&ograve;n',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'sem&egrave;n yo',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => 'pou koumanse vreman lenstalasyon',
'dirs_preliminaire' => 'Dab&ograve; : <b> ann swen drwa aks&egrave;</b>',
'dirs_probleme_droits' => 'Pwobl&egrave;m ak drwa laks&egrave;',
'dirs_repertoires_absents' => '<p><b>Oken r&eacute;pertwa sa-yo te fin rannkont&nbsp;:</b></p><ul>@bad_dirs@</ul>
  <p>  Pet&egrave;t yon pwobl&egrave;m ek majiskil ousinon miniskil ki pa bon.
  Gad yo ap mache kom kisa ap par&egrave;t isit anl&egrave;
 ; sinon, f&ograve;k w rele yon l&ograve;t fwa tout repertwar sa-yo nan ou logisy&egrave;l FTP pou korij er&egrave;-a.</p>
  <p>Kan laf&egrave; ke fini, w ke kapab',
'dirs_repertoires_suivants' => '<b>Pa posib ekri sou rep&egrave;twa sa-yo&nbsp;: <ul>@bad_dirs@.</ul> </b>
  <p>Pou swen bagay-la, ann itilize logisy&egrave;l FTP ou pou don drwa laks&eacute; chak
 rep&egrave;twa. Guid lenstalasyon ap di kouman w ke kapab f&egrave; bagay-la.
  </p><p>Kan w ke fini w ke kapab</p>', # MODIF
'double_occurrence' => 'Double occurrence', # MODIF

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Tay&nbsp;:',
'entree_titre_document' => 'Kouman dokiman i rele&nbsp;:',
'entree_titre_image' => 'Kouman imaj i rele&nbsp;:',
'envoi_via_le_site' => 'Voye ek sit-la',
'erreur' => 'Erreur', # NEW
'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :', # NEW
'erreur_texte' => 'erreur(s)', # NEW
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'Oken fisy&eacute; @fichier@ konsa',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'W se deja enskri.',
'form_email_non_valide' => 'Ladr&egrave;s lim&egrave;l ou se pa bon.',
'form_forum_access_refuse' => 'W pli ap gen lakse sou sit-la.',
'form_forum_bonjour' => 'Bonjou @nom@,,',
'form_forum_email_deja_enregistre' => 'Adr&egrave;s lim&egrave;l-a deja enskri, w p&eacute; itiliz  modpas &ograve;din&egrave; ou.',
'form_forum_identifiant_mail' => 'Nouvo lidantifyan ou s&eacute; voye andan bwatlim&egrave;l ou. ',
'form_forum_identifiants' => 'Idantifyan p&egrave;son&egrave;l yo',
'form_forum_indiquer_nom_email' => 'Enskri kouman w rele ak ladr&egrave;s lim&egrave;l ou Lidantifyan p&egrave;son&egrave;l ou ke vini apr&egrave; vitman andan bwatlim&egrave;l ou.',
'form_forum_login' => 'nonkod :',
'form_forum_message_auto' => '(mesaj-la se yon mesaj otomatik)',
'form_forum_pass' => 'modpas :',
'form_forum_probleme_mail' => 'Pwobl&egrave;m pou lim&egrave;l&nbsp;: lidantifyan pa posib anvway w.',
'form_forum_voici1' => 'Lidantifyan y perm&eacute; w soutni lavi
 sit-la "@nom_site_spip@" (@adresse_site@) :', # MODIF
'form_forum_voici2' => 'Lidantifyan ou pou pwopoze atik yo sou
sit "@nom_site_spip@" (@adresse_login@) :', # MODIF
'form_indiquer_email' => 'M&egrave;si enskri ladr&egrave;s lim&egrave;l ou.',
'form_indiquer_nom' => 'M&egrave;si enskri kouman w rele',
'form_indiquer_nom_site' => 'M&egrave;si enskri kouman sit ou-a li rele',
'form_pet_adresse_site' => 'Ladr&egrave;s sit ou',
'form_pet_aucune_signature' => 'Okenn siyati ka koresponn kod-la...',
'form_pet_confirmation' => 'M&egrave;si konfime siyati ou :',
'form_pet_deja_enregistre' => 'Sit-la se deja enskri',
'form_pet_deja_signe' => 'W te deja sinye t&egrave;ks-la.',
'form_pet_envoi_mail_confirmation' => 'Yon lim&egrave;l pou konfine te fin voye a w. F&ograve;k w vizite ladr&egrave;s w&egrave;b te done nan lim&egrave;l pou w konfime siyati ou.', # MODIF
'form_pet_mail_confirmation' => 'Bonjou,

W la domman m&egrave;t siyati nan petisyon-nan :
@titre@.

W te done tout rans&eacute;ynman  swivan :
    Kouman rele: @nom_email@
    sit ou: @nom_site@ - @url_site@

...

Pou konfime siyati-a, f&ograve;k s&egrave;lman w ab&ograve;d ladr&egrave;s anba (sinon, sitw&egrave;b-la ke pa enskri siyati ou) :
    @url@

M&egrave;si  w soutni petisyon-nan
', # MODIF
'form_pet_message_commentaire' => 'Gen yon mesaj, yon komant&eacute; pou di&nbsp;?',
'form_pet_nom_site2' => 'Kouman sitw&egrave;b ou rele',
'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
'form_pet_probleme_technique' => 'Pwobl&egrave;m teknik, siyati se pa posib kounye-a. Tann pwobl&egrave;m-la ke aranje pou rete sispann a yo.',
'form_pet_signature_pasprise' => 'Siyati ou se pa aksepte.',
'form_pet_signature_validee' => 'Siyati ou se konfime. M&egrave;si&nbsp;!',
'form_pet_site_deja_enregistre' => 'Sit-la se deja enskri',
'form_pet_url_invalide' => 'URL w te done se pa bon.',
'form_pet_votre_email' => 'Ladr&egrave;s lim&egrave;l ou',
'form_pet_votre_nom' => 'Kouman w rele',
'form_pet_votre_site' => 'Si w ap gen sitw&egrave;b, se posib enskri ali isit-enba-m&egrave;m',
'form_prop_confirmer_envoi' => 'Konfime w vle voye i',
'form_prop_description' => 'Dekrisyon/komant&egrave;',
'form_prop_enregistre' => 'Pwopozisyon ou se kounye-a  ap enskri, li ke par&egrave;t apre yon komand&egrave; te konfime ali. ',
'form_prop_envoyer' => 'Voye yon mesaj',
'form_prop_indiquer_email' => 'M&eacute;si enskri yon ladr&egrave;s lim&egrave;l ka mache',
'form_prop_indiquer_nom_site' => 'M&egrave;si enskri kouman sit ou rele',
'form_prop_indiquer_sujet' => 'M&egrave;si &eacute;kri yon sij&eacute;',
'form_prop_message_envoye' => 'Mesaj te fin voye',
'form_prop_nom_site' => 'Kouman sit la i rele',
'form_prop_non_enregistre' => 'Pwopozisyon ou te pa rojistr&eacute;',
'form_prop_sujet' => 'Sije',
'form_prop_url_site' => 'Ladr&egrave;s (URL) sitw&egrave;b',
'forum_acces_refuse' => 'W ap pli laks&eacute; pou fowom-nan.',
'forum_attention_dix_caracteres' => '<b>Atansyon&nbsp;!</b> mesaj ou li se mwen di l&egrave;t.',
'forum_attention_trois_caracteres' => '<b>Atansyon&nbsp;!</b> Kouman i rele sit-la se mwen trwa l&egrave;t. F&ocirc;k w m&egrave;t trwa l&egrave;t omwen',
'forum_attention_trop_caracteres' => '<b>Atansyon&nbsp;!</b> mesaje a w se tro lon (@compte@ caract&egrave;res)&nbsp;: f&ograve;k w respek @max@ karakt&egrave;r pou enskri ali.',
'forum_avez_selectionne' => 'W te chwazi&nbsp;:',
'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>isit</a> pou kontinye.',
'forum_forum' => 'fowom',
'forum_info_modere' => 'Fowom la se mod&eacute;w&eacute;-avann&nbsp;: patisipasyon demoun ke apar&egrave;t s&egrave;lman apr&eacute; yon komand&egrave;r  sit te valide ali.',
'forum_lien_hyper' => '<b>Lyen ip&egrave;rt&egrave;ks</b> (w pa oblij&eacute;)',
'forum_message_definitif' => 'Mesaj fin fini : anvway anndan sit la',
'forum_message_trop_long' => 'Mesaj ou se tro lon. Pli gran tay se 20000 kawakt&egrave;.',
'forum_ne_repondez_pas' => 'Reponn pa lim&egrave;l la. Reponn anndan fowom-an sou ladr&egrave;s la :',
'forum_non_inscrit' => 'W ap pa enskri ank&ograve;, oubyen ladr&egrave;s osinon modpas ou se pa kor&egrave;k.',
'forum_page_url' => '(Si mesaj ou ka voye sou yon tik sou W&egrave;b d&eacute;&ograve; ou yon l&ograve;t paj pli konpl&eacute;, m&egrave;si m&egrave;t anba kouman paj la  ka rele &egrave;k ladr&egrave;s URL.)',
'forum_par_auteur' => 'se @auteur@ te ekri',
'forum_poste_par' => 'Mesaj te poste @parauteur@ anba atik ou-a.', # MODIF
'forum_probleme_database' => 'Pwobl&egrave;m ak bazdone, mesaj ou te pa enskri.',
'forum_qui_etes_vous' => '<b>Kouman w rele ?</b> (pa oblij&eacute;)',
'forum_texte' => 'Teks mesaj ou :',
'forum_titre' => 'Kouman i rele mesaj ou :',
'forum_titre_erreur' => 'Er&egrave; ...',
'forum_url' => 'URL :',
'forum_valider' => 'Apiy&eacute; chwa-a',
'forum_voir_avant' => 'Gad mesaj la avan post ali',
'forum_votre_email' => 'Ladr&egrave;s lim&egrave;l ou :',
'forum_votre_nom' => 'Kouman w rele (ousinon kouman w vl&eacute; rele isit) :',
'forum_vous_enregistrer' => 'Pou soutni andan
 fowom-nan, f&ograve;k w enskri avan. M&eacute;si
 m&egrave;t enba lidantifyan p&egrave;son&egrave;l ou-a 
 kis nou t&eacute; don a w. Si w ap pa enskri ank&ograve;, f&ograve;k w',
'forum_vous_inscrire' => 'enskri w.',

// I
'ical_texte_rss_articles' => 'Fichy&eacute; &laquo;backend&raquo; pou tout atik yo, w ke rannkont sou ladr&egrave;s la :',
'ical_texte_rss_articles2' => 'W kap gen ositou fichye yo &laquo;backend&raquo; la pou tout atik yo nan chak ribrik sit la:',
'ical_texte_rss_breves' => 'Plis gen yon fichye ka kontni tout tinouv&egrave;l yo pou sit la. W kap gen s&egrave;lman tinouv&egrave;l yo yon ribrik pr&eacute;si si w domann yon nim&eacute;wo ribrik la s&egrave;lman. ',
'icone_a_suivre' => 'Ak&egrave;y',
'icone_admin_site' => 'Kolonaj sit la',
'icone_agenda' => 'Ajenda',
'icone_aide_ligne' => 'Bourad',
'icone_articles' => 'Atik yo',
'icone_auteurs' => 'Lot&egrave; yo',
'icone_breves' => 'Tinouv&egrave;l yo',
'icone_brouteur' => 'Gad tout sit vitman',
'icone_configuration_site' => 'Konfigire sit',
'icone_configurer_site' => 'Konfigir sit ou',
'icone_creer_nouvel_auteur' => 'Kreye yon nouvo lot&egrave;',
'icone_creer_rubrique' => 'Kreye yon ribrik',
'icone_creer_sous_rubrique' => 'Kreye yon sou-ribrik',
'icone_deconnecter' => 'Rete koneksyon',
'icone_discussions' => 'Kozman yo',
'icone_doc_rubrique' => 'Dokiman yo nan ribrik yo',
'icone_ecrire_article' => 'Ekri yon nouvo atik',
'icone_edition_site' => 'Ledisyon',
'icone_forum_administrateur' => 'Fowom pou komand&egrave; yo',
'icone_forum_suivi' => 'Swiv tout fowom yo',
'icone_gestion_langues' => 'Okipe plizy&egrave; lang',
'icone_informations_personnelles' => 'Rans&egrave;yman p&egrave;son&egrave;l',
'icone_interface_complet' => 'Ent&egrave;fas konpl&eacute;',
'icone_interface_simple' => 'Ent&egrave;fas senp',
'icone_maintenance_site' => 'Swen pou sit la',
'icone_messagerie_personnelle' => 'Kazmod&eacute;kri',
'icone_mots_cles' => 'Mokle yo',
'icone_nouvelle_breve' => 'Ekri yon nouvo tinouv&egrave;l',
'icone_repartition_actuelle' => 'Afiche repatisyon kounye-a',
'icone_repartition_debut' => 'Afiche repatisyon depi koumansman',
'icone_repartition_visites' => 'Repatisyon vizit yo',
'icone_rubriques' => 'Ribrik yo',
'icone_sauver_site' => 'Sov sit la',
'icone_site_entier' => 'Tout sit sa m&egrave;m',
'icone_sites_references' => 'Sit referans&eacute; yo',
'icone_statistiques' => 'Rezilta estatistik sit la',
'icone_statistiques_visites' => 'Estatistik',
'icone_suivi_activite' => 'Gad lavi sit la',
'icone_suivi_actualite' => 'Evolisyon &nbsp;sit la',
'icone_suivi_forums' => 'Swiv/okipe tout fowom ',
'icone_suivi_pettions' => 'Swiv/ okipe tout petisyon  ',
'icone_suivi_revisions' => 'Chanjman nan atik yo',
'icone_supprimer_document' => 'Kraze dokiman nan',
'icone_supprimer_image' => 'Kraze imaj la',
'icone_supprimer_message' => 'Kraze mesaj la',
'icone_tous_articles' => 'Tout atik ou',
'icone_tous_auteur' => 'Tout lot&egrave; yo',
'icone_valider_message' => 'Konfime mesaj la',
'icone_visiter_site' => 'F&egrave; yon vire',
'icone_voir_en_ligne' => 'Gad an liy',
'image_tourner_180' => 'Toun&eacute; 180&deg;',
'image_tourner_droite' => 'Toun&eacute; 90&deg; drwat ',
'image_tourner_gauche' => 'Toun&eacute; 90&deg; g&ograve;ch',
'img_indisponible' => 'imaj-la se pa disponib',
'impossible' => 'enposib',
'info_a_suivre' => 'AKEY&nbsp;&raquo;',
'info_a_valider' => '[pou konfime]',
'info_acces_interdit' => 'Aks&egrave; ent&egrave;di',
'info_acces_refuse' => 'Aks&egrave; refize',
'info_action' => 'Aksyon: @action@',
'info_administrer_rubriques' => 'W kapab j&egrave;re ribrik-la ek souribrik yo',
'info_adresse_non_indiquee' => 'W te pa done oken ladr&egrave;s pou eseye&nbsp;!',
'info_aide' => 'ED :',
'info_ajouter_mot' => 'Ajoute mokle-a',
'info_annonce' => 'ANNONS',
'info_annonces_generales' => 'Annons pou toutmoun&nbsp;:',
'info_article_propose' => 'Atik ki pwopoze ',
'info_article_publie' => 'Atik ki pibliy&eacute;',
'info_article_redaction' => 'Atik ki ap ekri ank&ograve;',
'info_article_refuse' => 'Atik ki refize',
'info_article_supprime' => 'Atik ki kraze',
'info_articles' => 'Atik yo',
'info_articles_a_valider' => 'Atik yo ki pou konfime',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Atik sa-yo se atik yo moun ki pwopoz&eacute;',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'lot&egrave; (yo)&nbsp;:',
'info_authentification_ftp' => 'Lotantifikasyon (pa FTP).',
'info_bloquer_lien' => 'blok lyen nan',
'info_breves_02' => 'Tinouv&egrave;l yo',
'info_breves_2' => 'tinouv&egrave;l yo',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Tinouv&egrave;l yo ki tann yon komand&egrave; konfime',
'info_connexion_refusee' => 'Koneksyon te fin refize',
'info_contact_developpeur' => 'M&egrave;si kotenouye yon devlop&egrave;r.',
'info_contenance' => 'Kisa ap kontni nan sit-la&nbsp;:',
'info_contribution' => 'mesaj andan fowom',
'info_copyright' => '@spip@ se yon logisy&egrave;l lib ki done @lien_gpl@.',
'info_copyright_doc' => 'Si w vle plis enf&ograve;masyon, ann gad sit sa-a <a href="@spipnet@">http://www.spip.net/cpf</a>.', # MODIF
'info_copyright_gpl' => 'nan lisans GPL',
'info_cours_edition' => 'Tout atik yo w ka ekri ank&ograve;',
'info_creer_repertoire' => 'Kreye yon fichye ousinon yon r&eacute;p&egrave;twa sak i rele&nbsp;:',
'info_creer_repertoire_2' => 'nan sou-rep&egrave;twa <b>@repertoire@</b>, epi&nbsp;:', # MODIF
'info_creer_vignette' => 'kreyasyon viy&egrave;t otomatik ',
'info_deplier' => 'Etann',
'info_descriptif_nombre' => 'dekrisyon(yo)&nbsp;:',
'info_description' => 'Dekrisyon&nbsp;:',
'info_description_2' => 'Dekrisyon&nbsp;:',
'info_dimension' => 'Tay&nbsp;:',
'info_document' => 'Dokiman',
'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
'info_documents' => 'Dokiman yo',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP ka p&eacute;m&egrave; lechanj mesaj ek kreyasyon fowom kozman priv&eacute;
 ant tout moun ka soutni sit la. W kap m&egrave;t oubyen kraze fonksyonalite a.',
'info_ecire_message_prive' => 'Ekri yon mesaj prive',
'info_email_invalide' => 'Adr&egrave;s lim&egrave;l se pa bon.',
'info_en_cours_validation' => 'Atik sa-yo se tout atik w yo ki ap ekri ank&ograve;',
'info_en_ligne' => 'Moun ki ap an liy&nbsp;:',
'info_envoyer_message_prive' => 'Voye yon mesaj prive pou lot&egrave;-a',
'info_erreur_requete' => 'Er&egrave; nan rek&egrave;t :',
'info_erreur_squelette2' => 'Oken leskel&egrave;t <b>@fichier@</b> se pa disponib...',
'info_erreur_systeme' => 'Er&egrave; sist&egrave;m (errno @errsys@)',
'info_erreur_systeme2' => 'Disk&eacute;dir se pet&egrave;t plen osnon bazdon&eacute; gen domaj <br />
 <font color=\'red\'>Esey w<a href=\'@script@\'>aranje baz-la</a>,
 osnon kontak l&eacute;b&egrave;j&egrave; ou.</font>', # MODIF
'info_fini' => 'W gen fin fini !',
'info_format_image' => 'K&egrave;k s&ograve;t imaj SPIP kapab itilize pou kreye viny&egrave;t&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'f&ograve;ma ki pa defini',
'info_grand_ecran' => 'Gran l&eacute;kran',
'info_image_aide' => 'ED',
'info_image_process_titre' => 'Kouman f&egrave; pou kreye k&egrave;k viny&egrave;t',
'info_impossible_lire_page' => '<b>Er&egrave; !</b> F&egrave; lekti paj <tt><html>@test_proxy@</html></tt> pa proksi ou-a se pa posib  <tt>', # MODIF
'info_inclusion_directe' => 'Enklizyon dir&egrave;k&nbsp;:',
'info_inclusion_vignette' => 'Enklizyon viy&egrave;t sa-a&nbsp;:',
'info_installation_systeme_publication' => 'Enstalasyon sist&egrave;m de piblikasyon...',
'info_installer_documents' => 'W kap enstal&eacute; otomatikman tout dokiman yo ki kontni nan dosy&eacute;-a @upload@.', # MODIF
'info_installer_ftp' => 'Tankou komand&egrave;, w kap enstal&eacute;(pa FTP)k&egrave;k fichy&eacute; nn dosy&eacute;-a @upload@ pou apr&egrave; w kap chwazi yo isit-la direkman.', # MODIF
'info_installer_images' => 'W kapab enstale k&egrave;k imaj nan f&ograve;ma sa-yo JPEG, GIF ak PNG.',
'info_installer_images_dossier' => 'Enstal imaj nan dosye @upload@ pou w ke kapab swazi yo isit apr&egrave;.', # MODIF
'info_installer_tous_documents' => 'Enstal tout dokiman',
'info_interface_complete' => 'ent&egrave;fas konpl&eacute;',
'info_interface_simple' => 'Ent&egrave;fas senp',
'info_joindre_document_article' => 'W kap jwenn sou atik-la tout dokiman nan tip',
'info_joindre_document_rubrique' => 'Nan ribrik-la, w kap ajoute tout dokiman nan tip',
'info_joindre_documents_article' => 'W kap jwenn nan atik ou-a, tout dokiman nan tip&nbsp;:',
'info_l_article' => 'atik sa-a',
'info_la_breve' => 'tinouv&egrave;l-la',
'info_la_rubrique' => 'ribrik la',
'info_langue_principale' => 'Lalang prensipal nan sit-la',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ piksel yo',
'info_les_auteurs_1' => 'pa @les_auteurs@',
'info_logo_format_interdit' => 'W selman kapab itilize yon logo nan f&ograve;ma @formats@.',
'info_logo_max_poids' => 'Fok logo yo se mwen @maxi@ (fichye sa-a se @actuel@).',
'info_logo_max_taille' => 'Fok logo yo se mwen @maxi@ (fichye sa-a se @actuel@).',
'info_mail_fournisseur' => 'w@fournisseur.com',
'info_message_2' => 'MESAJ',
'info_message_supprime' => 'MESAJ KRAZE',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Ladat piblikasyon&nbsp;:',
'info_modification_parametres_securite' => 'chanjman sou param&egrave;t pou sekirite',
'info_mois_courant' => 'Nan tan mwa-a :',
'info_mot_cle_ajoute' => 'Mokle-a te fin ajoute sou',
'info_multi_herit' => 'Lalang ka par&egrave;t otomatikman',
'info_multi_langues_soulignees' => 'Tout <u>lang souliy&eacute; sa-yo</u> ap gen yon tradiksyon tout t&egrave;ks sa-yo nan lent&egrave;fas. Si w chwazi lang sa-yo, genyen plen &eacute;l&eacute;man sou sit piblik (dat, f&ograve;mul&egrave;)ki tradwi otomatikman. Pou tout lang ki pa souliy&eacute; an,  tout &eacute;l&eacute;man sa-yo ke par&egrave;t nan lang prensipal sit ou.', # MODIF
'info_multilinguisme' => 'Miltilengwism',
'info_nom_non_utilisateurs_connectes' => 'Kouman ou rele pap par&egrave;t nan lis zitilizat&egrave; an liy.',
'info_nom_utilisateurs_connectes' => 'Kouman w rele ap par&egrave;t nan lis zitilizat&egrave;  an liy.',
'info_nombre_en_ligne' => 'Moun se an liy &nbsp;:',
'info_non_resultat' => 'gen pa oken r&eacute;zilta pou "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'W p\'ap itilize lakazmod&eacute;kri andan sit-la.',
'info_nouveau_message' => 'W GEN YON NOUVO MESAJ',
'info_nouveaux_messages' => 'W GEN @total_messages@ NOUVO MESAJ YO',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Sit sendike a se pa mache',
'info_pense_bete' => 'RAPLE-W',
'info_petit_ecran' => 'Piti l&eacute;kran',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'piks&egrave;l yo',
'info_plusieurs_mots_trouves' => 'K&egrave;k mokle te fin s&ograve;ti pou "@cherche_mot@":',
'info_popularite_5' => 'Kouman se popil&egrave;&nbsp;:',
'info_portfolio' => 'P&ograve;tfolio',
'info_portfolio_automatique' => 'Livlimaj otomatik&nbsp;:',
'info_premier_resultat' => '[@debut_limit@ premye rezilta sa-yo si  @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ premye rezilta sa-yo si @total@]',
'info_probleme_grave' => 'pwobl&egrave;m ek',
'info_propose_1' => '[@nom_site_spip@] ka pwopoze : @titre@',
'info_propose_2' => 'Atik pwopoze pou par&egrave;t
---------------',
'info_propose_3' => 'Atik "@titre@" pwopoze pou par&egrave;t.',
'info_propose_4' => 'W se invite pou vini gad ali ek donn anou  komant&egrave; ou',
'info_propose_5' => 'nan fowom anba. W trouv ali sou ladr&egrave;s:',
'info_publie_01' => 'Atik la i rele "@titre@" te konfime pa @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] KA PIBLIYE : @titre@',
'info_publie_2' => 'Atik se pibliye
--------------',
'info_rechercher' => 'Ch&egrave;che',
'info_rechercher_02' => 'Ch&egrave;che&nbsp;:',
'info_remplacer_vignette' => 'Chanje viny&egrave;t otomatik ek yon logo p&egrave;son&egrave;l&nbsp;:',
'info_retablir_lien' => 'Rom&egrave;t lyen-nan',
'info_retirer_mot' => 'Kraze mokle-a',
'info_retirer_mots' => 'Kraze tout mokle yo',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'ki pa rele',
'info_selectionner_fichier' => 'W kapab chwazi yon fichye nan dosy&eacute; @upload@', # MODIF
'info_selectionner_fichier_2' => 'Chwazi yon fichye&nbsp;:',
'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
'info_site_attente' => 'Sit web ki tann yon komand&egrave; konfime ali',
'info_site_reference' => 'Sit referanse an liy',
'info_site_refuse' => 'Sit we ki te fin refize',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referanse yon sit',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'kraze viy&egrave;t-la',
'info_symbole_bleu' => 'Senbol <b>ble</b> ki endik <b>yon pansb&egrave;t</b>: yon mesaj ou pou izaj p&egrave;son&egrave;l ou.', # MODIF
'info_symbole_jaune' => 'Senbol <b>jon</b> ki endik <b>yon anons pou tout redakt&egrave;</b>&nbsp;: ki visib pout tout redakt&egrave; nan espas prive, ak ki komand&egrave; kapab chanje selman.', # MODIF
'info_symbole_vert' => 'Senbol <b>v&egrave;r</b> ki endik <b> yon mesaj  voye ant zot zitilizat&egrave;</b> sit la.', # MODIF
'info_syndication' => 'sendikasyon&nbsp;:',
'info_syndication_articles' => 'atik (yo)',
'info_telecharger' => 'Telechaj sou l&ograve;dinat&egrave; ou&nbsp;:',
'info_telecharger_nouveau_logo' => 'T&eacute;l&eacute;chaj yon nouvo logo&nbsp;:',
'info_telecharger_ordinateur' => 'Telechaj sou l&ograve;dinat&egrave; ou&nbsp;:',
'info_tous_resultats_enregistres' => '[tout r&eacute;zilta yo ki enskri nan memwar ]',
'info_tout_afficher' => 'F&egrave; par&egrave;t tout',
'info_travaux_texte' => 'Sit-la p&ograve;k&ograve; konfigir&eacute;...Tounyen isit pli tar.',
'info_travaux_titre' => 'Sit ki se ank&ograve; yon chantye',
'info_trop_resultat' => 'Tro r&eacute;zilta pou "@cherche_mot@" ; M&egrave;si pr&eacute;siz ch&egrave;che ou.',
'info_utilisation_messagerie_interne' => 'W kapab itilize lakazmodekri andodan sit sa-a.',
'info_valider_lien' => 'konfime lyen sa-a',
'info_verifier_image' => ', m&egrave;si gad imaj sa-yo ki chaje kor&egrave;kman.',
'info_vignette_defaut' => 'Viy&egrave;t otomatik',
'info_vignette_personnalisee' => 'Viy&egrave;t p&egrave;son&egrave;l',
'info_visite' => 'vizit :',
'info_visites' => 'vizit yo :',
'info_vos_rendez_vous' => 'W ke rannkont',
'info_zoom' => 'gwoplan',
'infos_vos_pense_bete' => 'Mesaj yo pou w raple-w',
'item_breve_proposee' => 'Tinouv&egrave;l pwopoze pou par&egrave;t ',

// L
'lien_afficher_icones_seuls' => 'Afiche ik&ograve;n yo s&egrave;lman',
'lien_afficher_texte_icones' => 'Afiche ik&ograve;n ak t&egrave;ks',
'lien_afficher_texte_seul' => 'F&egrave; par&egrave;t kisa se t&egrave;ks s&egrave;lman',
'lien_liberer' => 'mawonn',
'lien_liberer_tous' => 'Mawonn tout atik sa-yo',
'lien_nouvea_pense_bete' => 'NOUVO RAPLE-W',
'lien_nouveau_message' => 'NOUVO MESAJ',
'lien_nouvelle_annonce' => 'YON NOUVEL ANNONS',
'lien_petitions' => 'PETISYON',
'lien_popularite' => 'popil&egrave;rit&eacute;&nbsp;: @popularite@%',
'lien_racine_site' => 'RASIN SIT-LA',
'lien_reessayer' => 'eseye ank&ograve; yon l&ograve;t fwa',
'lien_repondre_message' => 'Reponn sou sij&egrave; sa',
'lien_supprimer' => 'kraze',
'lien_tout_afficher' => 'F&egrave; par&egrave;t tout',
'lien_visite_site' => 'vizite sit sa-a',
'lien_visites' => '@visites@&nbsp;vizite yo',
'lien_voir_auteur' => 'Gad lot&egrave;-a',
'ligne' => 'Ligne', # NEW
'login' => 'Connexion', # NEW
'login_acces_prive' => 'akse nan espas prive',
'login_autre_identifiant' => 'kon&egrave;k w sou sit-la ek yon l&ograve;t idantifyan',
'login_cookie_accepte' => 'M&egrave;si r&egrave;g navigat&egrave; ou po li as&egrave;pt (pou sit la omwen)',
'login_cookie_oblige' => 'Pou w genyen idantify&eacute; nan manyen sir sou sit-la, f&ograve;k w as&egrave;pte gatomakro.',
'login_deconnexion_ok' => 'Koneksyon se fini.',
'login_erreur_pass' => 'Er&egrave; ak modpas-la.',
'login_espace_prive' => 'espas priv&eacute;',
'login_identifiant_inconnu' => 'Lidantifyan-nan &laquo; @login@ &raquo; li se pa rokoni.',
'login_login' => 'Nonnkod :',
'login_login2' => 'Nonnkod (idantifyan pou koneksyon sou sit-la)&nbsp;:',
'login_login_pass_incorrect' => '(Kouman w rele osnon modpas ou se pa kor&egrave;k.)',
'login_motpasseoublie' => 'modpas&nbsp;ki&nbsp;oubliy&eacute;&nbsp;?',
'login_non_securise' => 'Tansyon; F&ograve;mil&egrave; sa-a se pa sekirize. Si w vle pa
    modpas ou ke vole sou rezo, m&egrave;si aktive Javascript
  nan navigat&egrave; ek',
'login_nouvelle_tentative' => 'Ank&ograve; yon l&ograve;t esey',
'login_par_ici' => 'W se enskri... pa isit la...',
'login_pass2' => 'Modpas&nbsp;:',
'login_preferez_refuser' => '<b>Si w vl&eacute; refize tout gatomakro </b>, gen yon l&ograve;t m&eacute;t&ograve;d pou kon&egrave;kt a w (yon ki   gen pa pli gran s&eacute;kirit&eacute;)&nbsp;:',
'login_recharger' => 'Chaj ank&ograve; paj-la',
'login_rester_identifie' => 'Gad lidantifikasyon pou plizy&egrave; jou',
'login_retour_public' => 'Tounyen sou sit piblik',
'login_retour_site' => 'Tounyen sou sit piblik',
'login_retoursitepublic' => 'tounyen&nbsp;d&egrave;y&egrave;&nbsp;sou&nbsp;sit&nbsp;piblik',
'login_sans_cookiie' => 'Idantifikasyon ki gen pa pa oken gatomakro',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'enskri w',
'login_test_navigateur' => 'test navigat&egrave;/rekoneksyon',
'login_verifiez_navigateur' => '(Gad pou si navigat&egrave; ou li te pa raple modpas ou...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'kache tradiksyon yo',
'module_fichiers_langues' => 'Fichye-lang yo',

// N
'navigateur_pas_redirige' => 'Si navigat&egrave; ou se pa tounyen taptap sou yon l&ograve;t ladr&egrave;s web, m&egrave;si klik isit pou kontinye.',
'numero' => 'Num&eacute;ro', # NEW

// O
'occurence' => 'Occurrence', # NEW
'onglet_affacer_base' => 'Kraze labaz',
'onglet_auteur' => 'Lot&egrave;',
'onglet_contenu_site' => 'Kisa sit-la ka kontni',
'onglet_evolution_visite_mod' => '&Eacute;volisyon',
'onglet_fonctions_avances' => 'Tout fonksyon pw&eacute;si ',
'onglet_informations_personnelles' => 'Enf&ograve;masyon p&egrave;son&egrave;l',
'onglet_interactivite' => 'Ent&egrave;waktivite',
'onglet_messagerie' => 'Kazmod&eacute;kri',
'onglet_messages_internes' => 'Mesaj yo ki andan sit-la',
'onglet_messages_publics' => 'Mesaj piblik yo',
'onglet_messages_vide' => 'Mesaj yo ki gen pa oken t&egrave;ks',
'onglet_origine_visites' => 'Lorijin vizit yo',
'onglet_repartition_debut' => 'depi koumansman',
'onglet_repartition_lang' => 'Repatisyon ant lang',
'onglet_repartition_rubrique' => 'Repatisyon ant ribrik',
'onglet_save_restaur_base' => 'S&ograve;vgad/aranje labaz',
'onglet_vider_cache' => 'Vide kach-la',
'ortho_trop_de_fautes2' => 'Komans korije pli gwo f&ograve;t lotogwaf ek es&egrave;y apr&egrave; yon lot fwa.',

// P
'pass_choix_pass' => 'M&egrave;si chwazi nouvo modpas ou :',
'pass_erreur' => 'Er&egrave;',
'pass_erreur_acces_refuse' => '<b>Er&egrave; :</b> w gen pa pli oken aks&eacute; sou sit-la.',
'pass_erreur_code_inconnu' => '<b>Er&egrave; :</b> kod-la ap\'pa koresponn oken vizit&egrave; ki genyen aks&eacute; sou sit-la.',
'pass_erreur_non_enregistre' => '<b>Er&egrave; :</b> ladr&egrave;s <tt>@email_oubli@</tt> ap pa enskri sou sit-la.',
'pass_erreur_non_valide' => '<b>Er&egrave; :</b> lim&egrave;l sa-a <tt>@email_oubli@</tt> ki pa mache !',
'pass_erreur_probleme_technique' => '<b>Er&egrave; :</b> akoz yon pwobl&egrave;m teknik, se pa posib voye lim&egrave;l sa-a.',
'pass_espace_prive_bla' => 'Espas prive sit-la se ouv&egrave; pou tout vizit&egrave;
  ki enskri dab&ograve;. Kan w ap enskri w, w ke kapab,
  f&egrave; lekti tout atik ki ank&ograve; pou ekri ek pwopoze atik ou mem,
  osnon mem soutni nan tout fowom sit sa-a .',
'pass_forum_bla' => 'W ap domann soutni nan yon fowom ki r&eacute;z&egrave;ve
  pou vizit&egrave; ki deja enskri.',
'pass_indiquez_cidessous' => 'Endik isit anba ladr&egrave;s lim&egrave;l w ap enskri w dab&ograve;.
W
   ke genyen yon limel ki di w kouman w ke kapab rekip&egrave; laks&eacute; ou.
',
'pass_mail_passcookie' => '(Tala se mesaj otomatik)
Pou w genyen ank&ograve; lakse ou sou sit-la
@nom_site_spip@ (@adresse_site@)

M&egrave;si f&egrave; yon vir&eacute; sou ladr&egrave;s la :

    @sendcookie@

W ke kapab al&ograve; enskri yon nouvo modpas
ak tounyen d&eacute;y&eacute; konekte sou sit-la.

', # MODIF
'pass_mot_oublie' => 'Modpas ki oubliye',
'pass_nouveau_enregistre' => 'Nouvo modpas ou-a se enskri nan m&eacute;mwar.',
'pass_nouveau_pass' => 'Nouvo modpas',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Modpas ki oublye ',
'pass_quitter_fenetre' => 'Lage fin&egrave;t-la',
'pass_rappel_login' => 'Raple : lidantifyan ou-a (nondkod) se &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'W ke genyen yon lim&egrave;l ki di w kouman w kapab rekip&egrave; laks&eacute; ou sou sit sa-a.',
'pass_retour_public' => 'Tounyen d&eacute;y&egrave; sou sit piblik',
'pass_rien_a_faire_ici' => 'Genyen pa ryen pou f&egrave; isit.',
'pass_vousinscrire' => 'Enskri w sou sit sa-a',
'precedent' => 'd&eacute;y&egrave;',
'previsualisation' => 'Pou gade avan pibliye',
'previsualiser' => 'Gade avan pibliy&eacute;',

// R
'retour' => 'Retour', # NEW

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
'squelette' => 'eskelet',
'squelette_inclus_ligne' => 'eskelet enkli, liy',
'squelette_ligne' => 'eskelet,liy',
'stats_visites_et_popularite' => '@visites@ vizit yo&nbsp;; kouman se popil&egrave;&nbsp;: @popularite@',
'suivant' => 'swivan',

// T
'taille_ko' => '@taille@&nbsp;ko',
'taille_mo' => '@taille@&nbsp;Mo',
'taille_octets' => '@taille@&nbsp;okt&egrave;',
'texte_actualite_site_1' => 'Kan w genyen abitid ek lent&egrave;fas, w ke kapab piy&eacute; sou &laquo;',
'texte_actualite_site_2' => 'ent&egrave;fas konpl&eacute;',
'texte_actualite_site_3' => '&raquo; pou genyen plis posibilite.',
'texte_creation_automatique_vignette' => 'Kreyasyon otomatik tout viy&egrave;t pou gade avan pibliy&eacute; ap mache jodiya sou sit-la. Si w enstal ek f&ograve;mil&egrave; sa-a imaj yo nan f&ograve;ma (sa-yo) @gd_formats@, yo ke vini ak yon viy&egrave;t ki tay pli gran se @taille_preview@&nbsp;piksel.',
'texte_documents_associes' => 'Dokiman swivan sa-yo se asosye ek atik-la,
    poutan yo genyen pa dir&egrave;kman par&egrave;t nan atik-la. Kiswa kouman paj ou rosanm sou sit piblik,
    yo ki par&egrave;t nan f&ograve;m dokiman jwen.',
'texte_erreur_mise_niveau_base' => 'Ere ek bazdone pou m&egrave;t nan nivo.
  imaj <b>@fichier@</b>  sa-a ki pa rive (article @id_article@).
  Ekri r&eacute;f&eacute;rans-la, ek esey yon lot fwa
  aranje nivo, epi gade si imaj yo ki kapab par&egrave;t
  byen toujou nan atik yo.', # MODIF
'texte_erreur_visiteur' => 'W t eseye antre nan lespas priv&eacute; ak yon lidantifyan an ki pa rive p&egrave;m&egrave;t aksyon la.', # MODIF
'texte_inc_auth_1' => 'Kouman w rele pou genyen idantifye w 
 <b>@auth_login@</b>, soman li pli/pa egsite nan bazdone. 
  Esey', # MODIF
'texte_inc_auth_2' => 'kon&egrave;k w ank&ograve; yon lot fwa',
'texte_inc_auth_3' => ', apr&egrave; w p&egrave;t&egrave;t lage &eacute;pi
 r&egrave;t ek d&eacute;mar yon lot fwa navigat&egrave; ou.',
'texte_inc_config' => 'Tout chanjman nan paj sa-yo genyen gran enflians si manyen sit-la ka mache.
 L&egrave;s azot bagay-la sou kote kounyen-a, si w genyen p&ograve;k&ograve; gran abitid ak manyen kouman SPIP mache.
<br /><br /><b> Ann
l&egrave;s plit&ograve; jestyon paj sa-yo pou w&egrave;bm&egrave;t prensipal sou sit-la.</b>', # MODIF
'texte_inc_meta_1' => 'Sist&egrave;m la ki genyen yon er&egrave; ak l&eacute;kriti fichye <code>@fichier@</code>. M&egrave;si, w ki komand&egrave; sit-la,', # MODIF
'texte_inc_meta_2' => 'gade tout drwa l&eacute;kriti se korek',
'texte_inc_meta_3' => 'nan r&eacute;p&egrave;twa <code>@repertoire@</code>.', # MODIF
'texte_statut_en_cours_redaction' => 'ank&ograve; pou ekri',
'texte_statut_poubelle' => 'nan bwat poub&egrave;l',
'texte_statut_propose_evaluation' => 'pwopoze pou jijman',
'texte_statut_publie' => 'pibliye an ly',
'texte_statut_refuse' => 'refize',
'titre_ajouter_mot_cle' => 'AJOUTE YON MOKLE :',
'titre_breve_proposee' => 'Tinouv&egrave;l pwopoze pou par&egrave;t',
'titre_breve_publiee' => 'Tinouv&egrave;l ki pibliye an liy',
'titre_breve_refusee' => 'Tinouv&egrave;l ki refize',
'titre_cadre_raccourcis' => 'TICHEMEN YO :',
'titre_changer_couleur_interface' => 'Chanje koul&egrave; lent&egrave;fas',
'titre_forum' => 'Fowom',
'titre_image_admin_article' => 'W kapab j&egrave;re atik-la',
'titre_image_administrateur' => 'Komand&egrave;',
'titre_image_aide' => 'Ann genyen &egrave;d sou eleman nan',
'titre_image_auteur_supprime' => 'Lot&egrave; te kraze',
'titre_image_redacteur' => 'Redakt&egrave; ap gen pa aks&egrave;',
'titre_image_redacteur_02' => 'Redakt&egrave;',
'titre_image_visiteur' => 'Vizit&egrave;',
'titre_joindre_document' => 'JWENN YON DOKIMAN',
'titre_liens_entrants' => 'Lyen sa-yo ka rive',
'titre_mots_cles' => 'MOKLE YO',
'titre_probleme_technique' => 'Atansyon&nbsp;: yon pxobl&egrave;m teknik (s&egrave;rv&egrave;r SQL) fe entediksyon antre nan pati a nan sit sa a. M&eacute;si konprann.', # MODIF
'titre_publier_document' => 'PIBLIYE YON DOKIMAN NAN PATI A NAN SIT SA A',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Estatistik sit la',
'titre_titre_document' => 'Kouman rele dokiman a&nbsp;:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(atik pou referans)',

// Z
'zbug_balise_b_aval' => '&nbsp;: baliz B anba',
'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n\'existe pas', # MODIF
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'boukle',
'zbug_boucle_recursive_undef' => 'boukle rekisiv ki pa d&eacute;fini', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Chan @champ@ ki pa nan boukle',
'zbug_champ_hors_motif' => 'Chan @champ@ ki pa nan boukle-motif @motif@', # MODIF
'zbug_code' => 'kod',
'zbug_critere_inconnu' => 'krit&egrave; sa-a se pa koni @critere@', # MODIF
'zbug_distant_interdit' => 'd&eacute;&ograve; ent&egrave;di', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: d&eacute;finisyon doub', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: tag pou f&egrave;me ap pa egsiste ', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Sintaks boukl pa kor&egrave;k', # MODIF
'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
'zbug_erreur_execution_page' => 'er&egrave; nan leks&eacute;kisyon paj la', # MODIF
'zbug_erreur_filtre' => 'Er&egrave;: fil <b>&laquo; @filtre@ &raquo;</b> se pa defini ', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} ki pa mache ak (FORUMS) oubyen (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Er&egrave; nan l&egrave;skel&egrave;t',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'Er&egrave; sou sit-la',
'zbug_inversion_ordre_inexistant' => 'yon ord ki pa egziste genyen lanv&egrave;', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
'zbug_parametres_inclus_incorrects' => 'Param&egrave;t pou enklizyon se pa korek', # MODIF
'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
'zbug_resultat' => 'r&eacute;zilta',
'zbug_serveur_indefini' => 's&egrave;v&egrave; SQL ki pa defini', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Tab SQL &laquo; @table@ &raquo; se pa koni',
'zxml_connus_attributs' => 'attributs connus', # NEW
'zxml_de' => 'de', # NEW
'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
'zxml_inconnu_balise' => 'balise inconnue', # NEW
'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
'zxml_inconnu_id' => 'ID inconnu', # NEW
'zxml_mais_de' => 'mais de', # NEW
'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
'zxml_non_fils' => 'n\'est pas un fils de', # NEW
'zxml_nonvide_balise' => 'balise non vide', # NEW
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
'zxml_survoler' => 'survoler pour voir les corrects', # NEW
'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
'zxml_vide_balise' => 'balise vide', # NEW
'zxml_vu' => 'vu auparavant', # NE
);

?>
